#!/usr/bin/python
# -*- coding: UTF-8 -*-
#
#The MIT License
#
#Copyright (c) 2011
#
#Permission is hereby granted, free of charge, to any person obtaining a copy
#of this software and associated documentation files (the "Software"), to deal
#in the Software without restriction, including without limitation the rights
#to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#copies of the Software, and to permit persons to whom the Software is
#furnished to do so, subject to the following conditions:
#
#The above copyright notice and this permission notice shall be included in
#all copies or substantial portions of the Software.
#
#THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
#THE SOFTWARE.
#
#Authors:
#   Vili Auvinen (vili.k.auvinen@jyu.fi)
#   Olli Kauppinen (olli.kauppinen@jyu.fi)
#   Juho Tammela (juho.i.tammela@jyu.fi)

'''This module contains a function for sending email.

@author: Juho Tammela
'''
from smtplib import SMTP
from email.MIMEText import MIMEText
#from email.MIMEMessage import MIMEMessage
from urllib import unquote

def index(req):
    '''The main function called by a JavaScript file asynchronously. Sends email to the user.
    
    Email address and message body is stored in the Request-object.
    
    @param req: Mod_Python request object holding information given in the Ajax-call.

    @return: Sring to indicate success or failure in sending email. String can be parsed as XML because of Internet Explorer.
    
    Internet Explorer wants xml as response, else it thinks something went wrong when it tries to parse xml out of the response and doesn't succeed!    
    '''
    #Couldn't get this to show scandinavian characters properly in the email-message with utf-8 although the html-page is in utf-8.
    #iso-8859-1 seems to work though.
    
    req.content_type = "text/xml; charset=ISO-8859-1"
    #req.content_type = "text/xml; charset=utf-8"
    
    emailAddress = req.form.getfirst("email")
    body = unquote(req.form.getfirst("data")).decode('iso-8859-1').encode('iso-8859-1')

#    for body_charset in 'ASCII', 'ISO-8859-1', 'UTF-8', 'UTF-16':
#        try:
#            body.encode(body_charset)
#        except UnicodeError:
#            pass
#        else:
#            break

#    msg = MIMEText(body.encode(body_charset), 'plain', body_charset)

    msg = MIMEText(body, 'plain', 'iso-8859-1')
    
    you = str(emailAddress)
    me = str(emailAddress)
    msg['From'] = me
    msg['To'] = you

    #Add more receivers here:
    #msg['Cc'] = third_party
    
    #The source text is utf-8.
    msg['Subject'] = 'Tietokone ja tietoverkot työvälineenä - palaute harjoitustyöstäsi!'.decode('utf-8')
    
    
    try:
        s = SMTP('smtp.jyu.fi')
        s.sendmail(me, you, msg.as_string())
        s.quit()
        #Internet Explorer wants xml as response, else it thinks something went wrong when it tries to parse xml out of the response and doesn't succeed!
        req.write("<status>200 OK</status>")
    except:
        #req.write(str(sys.exc_info()[0]))
        req.write("<status>ERROR</status>")