#!/usr/bin/python
# -*- coding: UTF-8 -*-
#
#The MIT License
#
#Copyright (c) 2011
#
#Permission is hereby granted, free of charge, to any person obtaining a copy
#of this software and associated documentation files (the "Software"), to deal
#in the Software without restriction, including without limitation the rights
#to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#copies of the Software, and to permit persons to whom the Software is
#furnished to do so, subject to the following conditions:
#
#The above copyright notice and this permission notice shall be included in
#all copies or substantial portions of the Software.
#
#THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
#THE SOFTWARE.
#
#Authors:
#   Vili Auvinen (vili.k.auvinen@jyu.fi)
#   Olli Kauppinen (olli.kauppinen@jyu.fi)
#   Juho Tammela (juho.i.tammela@jyu.fi)

'''This module provides the Mod_Python graphical user interface for the software.

@author: Juho Tammela
'''
import controller
from cgi import escape
from urllib import urlopen
from cStringIO import StringIO

def firstPage(name, nameError, email, emailError, fileDiskError, fileUrl, fileUrlError):
    '''Gets the form page of the interface as html string.'''
    
    return """<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="fi" >
  <head>
    <meta http-equiv="content-type" content="text/html; charset=UTF-8" />
    <link href="style.css" rel="StyleSheet" type="text/css" />
    <script src="jquery-1.5.2.min.js" type="text/javascript"></script>
    <script src="file_input_changer.js" type="text/javascript"></script>
    <title>Harkkatarkastin</title>
  </head>
  <body id="main">
    <h1>Tietokone ja tietoverkot työvälineenä - Harkkapoliisi</h1>
    <p>Päivitetty 19.5.2011 klo 17:57</p>
    <form action="" method="post" enctype="multipart/form-data">
      <fieldset>
        <legend>Harjoitustyön tiedot</legend>
        <p  class="evenTextBox">
          <label for="name">Tekijän nimi:</label>
          <input type="text" id="name" name="name" size="50" value="%s"/>
          <span class="error">%s</span>
        </p>
        <p class="evenTextBox">
          <label for="email">Sähköposti:</label>
          <input type="text" id="email" name="email" size="50" value ="%s"/>
          <span class="error">%s</span>
        </p>
        <p>Tiedoston lataus:</p> 
        <p class="evenFileInput">
          <input id="radioDisk" type="radio" value="file" name="fileInputSelection" checked="checked"/>
          <label for="radioDisk">Levyltä:</label>               
          <input class="" type="file" id="filerequest" name="filerequest" />
          <span class="error">%s</span>
        </p>
        <p class="evenFileInput" >
          <input id="radioUrl" type="radio" value="url" name="fileInputSelection"/>
          <label for="radioUrl">URL:</label>        
          <input class="hidden" type="text" id="fileUrl" name="fileUrl" size="50" value="%s" />
          <span class="error">%s</span>
        </p>
        <p class="evenInput">
          <input type="submit" id="submitButton" name="submitButton" value="Tarkasta!" />
        </p>
        <p id="loading" class="hidden">Tarkastetaan... 
        <img src="http://sovellusprojektit.it.jyu.fi/parsi/sovellus/img/loading.gif" alt="Tarkastetaan dokumentteja." />
        </p>
      </fieldset>
    </form>
  </body>
</html>
""" % (name, nameError, email, emailError, fileDiskError, fileUrl, fileUrlError)

def feedBackPage(feedback, name, email):
    '''Gets the feedback page of the interface.'''
    
    page = """<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="fi">
  <head>
    <meta http-equiv="content-type" content="text/html; charset=UTF-8" />
    <link href="style.css" rel="StyleSheet" type="text/css" />
    <script src="jquery-1.5.2.min.js" type="text/javascript"></script>
    <script src="feedbackpage.js" type="text/javascript"></script>
    <title>Harkkatarkastin</title>
  </head>
  <body>
    <h1>Tietokone ja tietoverkot työvälineenä - Harkkapoliisi</h1>
    <p>
        Nimi: %s <input type="hidden" id="name" value="%s" />
    </p>
    <p>
        Sähköposti: %s <input type="button" id="sendToEmailButton" name="" value="Lähetä palaute myös sähköpostiin" /> <input type="hidden" id="emailAddress" value="%s" />
    </p>
    <p>Tarkastettu: <span id="date"></span></p>
""" % (name, name, email, email)

    for msg in feedback:
        page += msg

    page += """
  </body>
</html>
"""
    return page

def index(req):
    req.content_type = "text/html"
    form = req.form
    feedback = []
    name = form.getfirst("name")
    email = form.getfirst("email")
    sent = form.getfirst("submitButton")
    fileUrl = form.getfirst("fileUrl")
    radioValue = form.getfirst("fileInputSelection")
    #feedback.append(name)
    
    if sent:
        #feedback.append("Nimi: " + name)
        #feedback.append("Sähköpostiosoite: " + email)
        nameError = ""
        emailError = ""
        goForward = True
        
        if name == "" or name == None:
            nameError = "* Pakollinen kenttä!"
            goForward = False
        if  email == "" or email == None:
            emailError = "* Pakollinen kenttä!"
            goForward = False
        if goForward:
            tmpfile = None
            if radioValue.value == "file":
                tmpfile = req.form['filerequest']
                
                if tmpfile.filename == "":
                    inputError = "* Tiedostoa ei löytynyt!"
                    return firstPage(escape(name), nameError, escape(email), emailError, inputError, escape(fileUrl), "")
                controller.beginInspection(tmpfile.file, tmpfile.filename, feedback, email)
                
            elif radioValue.value == "url":
                try:                
                    tmpfile = urlopen(fileUrl)
                    controller.beginInspection(StringIO(tmpfile.read()), fileUrl, feedback, email)
                except IOError:
                    inputError = "* Url-osoite oli väärin!"
                    return firstPage(escape(name), nameError, escape(email), emailError, "", escape(fileUrl), inputError)
            #else: then what?
            
            return feedBackPage(feedback, escape(name), escape(email))
            
        else:
            sent = None
            return firstPage(escape(name), nameError, escape(email), emailError, "", escape(fileUrl), "")
    return firstPage("", "", "", "", "", "http://", "")
